{ inputs, pkgs, ... }:
{

  imports = [
    ./shell-conf/nushell/nushell.nix
    ./shell-conf/fish/fish.nix
  ];

  home.packages = with pkgs; [
    inputs.isd.packages.x86_64-linux.default

    razer-cli

    goimapnotify

    cmake
    cmake-format

    mediainfo
    gtrash

    just
    readline
    rlwrap
    yt-dlp
    age
    figlet
    ffmpeg-full
    ouch
    pinentry
    gcr
    gnutar
    libnotify
    unzip
    zip
    tldr
    rich-cli
    gnupg
    imagemagick

    nix-du
    nix-melt
    nix-tree

    usbutils
    pciutils
    util-linux
    coreutils
    binutils
    editorconfig-core-c
    exiftool
    libsecret
    shellcheck

    icloudpd
    pkg-config

    numbat
    nix-converter
    nurl
    fastfetch
    nvd
    ripgrep-all
    silver-searcher

    age
    manix
    caligula

    rink

    dua
    bluetui

    tree
    emoji-picker

    sox
    imgcat
    ghostscript
    playerctl
    tesseract
    dockfmt
    trash-cli
    poppler_utils

    television
    bash-env-json
    bash-env-nushell
    vivid

    caddy
    file
    visidata
    vips
    ffmpegthumbnailer

    termsonic

    hydra-check
  ];

  home.shellAliases = {
    "em" = "emacsclient -n -r";
    "fg" = "job unfreeze";
    "emm" = "emacsclient -nw";
    "gt" = "gtrash";
    "gtp" = "gtreash prune";
    "gtr" = "gtrash restore";
    "rmr" = "gtrash restore";
    "rm" = "gtrash put";
    "lg" = "lazygit";
    "cat" = "bat --plain";
    "sbcl" = "rlwrap sbcl";
    "yabup" = "yabridgectl sync --prune";
    "serve" = "caddy file-server -l :1234 -r";
  };

  programs = {
    bash = {
      enable = true;
    };
    nix-index = {
      enable = true;
    };
    direnv = {
      enable = true;
      nix-direnv.enable = true;
      config = {
        whitelist = {
          prefix = [ "~/source" "~/projects" ];
        };
      };
    };
    pay-respects = {
      enable = true;
    };
    zoxide = {
      enable = true;
    };
    starship = {
      enable = true;
    };
    ripgrep = {
      enable = true;
      package = (pkgs.ripgrep.override {withPCRE2 = true;});
    };
    ghostty = {
      enable = true;
    };
    wezterm = {
      enable = true;
      package = inputs.wezterm.packages.${pkgs.system}.default;
    };
    bat = {
      enable = true;
    };
    eza = {
      enable = true;
      git = true;
      icons = "auto";
      colors = "auto";
      package = inputs.eza.packages.${pkgs.system}.default;
    };
    fd = {
      enable = true;
    };
    fzf = {
      enable = true;
    };
    broot = {
      enable = true;
    };
    lazygit = {
      enable = true;
      settings = {
        nerdFontsVersion = "3";
        git = {
          paging.pager = "delta --paging=never";
        };
      };
    };
    jq.enable = true;
    rbw = {
      enable = true;
      package = pkgs.rbw;
    };
  };

  home.file = {
    ".local/bin" = {
      source = ./shell-conf/scripts;
      recursive = true;
    };
    ".local/share/flf".source = ./shell-conf/flf;
  };

  xdg.configFile = {
  "starship.toml".source = ./shell-conf/starship/starship.toml;
  "wezterm" = {
    recursive = true;
    source = ./shell-conf/wezterm;
  };
  "rbw".source = ./shell-conf/rbw;
  "isd_tui/config.yaml".source = ./shell-conf/isd_tui/config.yaml;
  };

}
